statuses

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package statuses provides a client for managing Redmine issue statuses.

Package statuses provides commands for managing Redmine issue statuses.

Package statuses provides types for managing Redmine issue statuses.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewCommand

func NewCommand(flags *types.GlobalFlags, resolver types.Resolver) *cobra.Command

NewCommand creates a new statuses command.

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client is a client for managing Redmine issue statuses.

func NewClient

func NewClient(c *client.Client) *Client

NewClient creates a new statuses client.

func (*Client) List

func (c *Client) List(ctx context.Context) (*IssueStatusList, error)

List retrieves all issue statuses.

type IssueStatus

type IssueStatus struct {
	ID        int    `json:"id"`
	Name      string `json:"name"`
	IsClosed  bool   `json:"is_closed"`
	IsDefault bool   `json:"is_default"`
	Position  int    `json:"position"`
}

IssueStatus represents a Redmine issue status.

type IssueStatusList

type IssueStatusList struct {
	IssueStatuses []IssueStatus `json:"issue_statuses"`
}

IssueStatusList represents a list of issue statuses.

Jump to