Documentation
¶
Overview ¶
Package app provides the CLI application commands and logic.
Package app provides the CLI application commands and logic.
Package app provides the CLI application commands and logic.
Package app provides the CLI application commands and logic.
Package app provides the CLI application commands and logic.
Package app provides the CLI application commands and logic.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewRootCommand ¶
NewRootCommand creates the root command for the CLI.
func ResolveClient ¶
func ResolveClient(flags *GlobalFlags) (*client.Client, error)
ResolveClient resolves the client based on the provided flags.
func ResolveFormat ¶
func ResolveFormat(flags *GlobalFlags) output.Format
ResolveFormat resolves the output format based on the provided flags.
func WriteOutput ¶
func WriteOutput(w io.Writer, flags *GlobalFlags, payload any) error
WriteOutput writes the output based on the provided flags and payload.
Types ¶
type GlobalFlags ¶
type GlobalFlags = types.GlobalFlags
GlobalFlags is an alias for types.GlobalFlags for backward compatibility